@@ -40,6 +40,7 @@ class Filters:
     """
     Use the methods and variables in this class to create and combine filters for tasks on the Label Studio Data Manager.
     """
+
     OR = 'or'
     """Combine filters with an OR"""
     AND = 'and'
@@ -47,7 +48,7 @@ class Filters:
 
     @staticmethod
     def create(conjunction, items):
-        """ Create a filter for `label_studio_sdk.project.Project.get_tasks()`
+        """Create a filter for `label_studio_sdk.project.Project.get_tasks()`
 
         Parameters
         ----------
@@ -62,10 +63,7 @@ class Filters:
             containing specified parameters
 
         """
-        return {
-          "conjunction": conjunction,
-          "items": items
-        }
+        return {"conjunction": conjunction, "items": items}
 
     @staticmethod
     def item(name, operator, column_type, value):
@@ -73,7 +71,7 @@ class Filters:
 
         Parameters
         ----------
-        name: `Column` | str
+        name: `Column` or str
             Column.id, Column.completed_at, Column.data('my_field'), etc
         operator: `Operator`
             Operator.EQUAL, Operator.GREATER_OR_EQUAL, Operator.IN, etc
@@ -87,15 +85,15 @@ class Filters:
         dict
         """
         return {
-            "filter": name,
+            "filter": 'filter:' + name,
             "operator": operator,
             "type": column_type,
-            "value": value
+            "value": value,
         }
 
     @staticmethod
     def datetime(dt):
-        """ Date time string format for filtering the Data Manager.
+        """Date time string format for filtering the Data Manager.
 
         Parameters
         ----------
@@ -141,8 +139,7 @@ class Filters:
 
 
 class Operator:
-    """Specify the operator to use when creating a filter.
-    """
+    """Specify the operator to use when creating a filter."""
 
     EQUAL = "equal"
     NOT_EQUAL = "not_equal"
@@ -161,8 +158,7 @@ class Operator:
 
 
 class Type:
-    """Specify the type of data in a column.
-    """
+    """Specify the type of data in a column."""
 
     Number = 'Number'
     Datetime = 'Datetime'
@@ -175,49 +171,48 @@ class Type:
 
 
 class Column:
-    """Specify the column on the Data Manager in Label Studio UI to use in the filter.
-    """
+    """Specify the column on the Data Manager in Label Studio UI to use in the filter."""
 
-    id = "filter:tasks:id"
+    id = "tasks:id"
     """Task ID"""
-    ground_truth = "filter:tasks:ground_truth"
+    ground_truth = "tasks:ground_truth"
     """Ground truth status of the tasks"""
-    annotations_results = "filter:tasks:annotations_results"
+    annotations_results = "tasks:annotations_results"
     """Annotation results for the tasks"""
-    reviewed = "filter:tasks:reviewed"
+    reviewed = "tasks:reviewed"
     """Whether the tasks have been reviewed (Enterprise only)"""
-    predictions_score = "filter:tasks:predictions_score"
+    predictions_score = "tasks:predictions_score"
     """Prediction score for the task"""
-    predictions_model_versions = "filter:tasks:predictions_model_versions"
+    predictions_model_versions = "tasks:predictions_model_versions"
     """Model version used for the predictions"""
-    predictions_results = "filter:tasks:predictions_results"
+    predictions_results = "tasks:predictions_results"
     """Prediction results for the tasks"""
-    file_upload = "filter:tasks:file_upload"
+    file_upload = "tasks:file_upload"
     """Name of the file uploaded to create the tasks"""
-    created_at = "filter:tasks:created_at"
+    created_at = "tasks:created_at"
     """Time the task was created at"""
-    annotators = "filter:tasks:annotators"
+    annotators = "tasks:annotators"
     """Annotators that completed the task (Community). Can include assigned annotators (Enterprise only)"""
-    total_predictions = "filter:tasks:total_predictions"
+    total_predictions = "tasks:total_predictions"
     """Total number of predictions for the task"""
-    cancelled_annotations = "filter: tasks:cancelled_annotations"
+    cancelled_annotations = "tasks:cancelled_annotations"
     """Number of cancelled or skipped annotations for the task"""
-    total_annotations = "filter:tasks:total_annotations"
+    total_annotations = "tasks:total_annotations"
     """Total number of annotations on a task"""
-    completed_at = "filter:tasks:completed_at"
+    completed_at = "tasks:completed_at"
     """Time when a task was fully annotated"""
-    agreement = "filter:tasks:agreement"
+    agreement = "tasks:agreement"
     """Agreement for annotation results for a specific task (Enterprise only)"""
-    reviewers = "filter:tasks:reviewers"
+    reviewers = "tasks:reviewers"
     """Reviewers that reviewed the task, or assigned reviewers (Enterprise only)"""
-    reviews_rejected = "filter:tasks:reviews_rejected"
+    reviews_rejected = "tasks:reviews_rejected"
     """Number of annotations rejected for a task in review (Enterprise only)"""
-    reviews_accepted = "filter:tasks:reviews_accepted"
+    reviews_accepted = "tasks:reviews_accepted"
     """Number of annotations accepted for a task in review (Enterprise only)"""
 
     @staticmethod
     def data(task_field):
-        """ Create a filter name for the task data field
+        """Create a filter name for the task data field
 
         Parameters
         ----------
@@ -229,36 +224,44 @@ class Column:
             Filter name for task data
 
         """
-        return "filter:tasks:data." + task_field
+        return "tasks:data." + task_field
 
 
 def _test():
     """Test it"""
-    filters = Filters.create(Filters.OR, [
-        Filters.item(
-            Column.id,
-            Operator.GREATER,
-            Type.Number,
-            Filters.value(42)
-        ),
-        Filters.item(
-            Column.completed_at,
-            Operator.IN,
-            Type.Datetime,
-            Filters.value(
-                datetime(2021, 11, 1),
-                datetime(2021, 11, 5),
-            )
-        )
-    ])
+    filters = Filters.create(
+        Filters.OR,
+        [
+            Filters.item(Column.id, Operator.GREATER, Type.Number, Filters.value(42)),
+            Filters.item(
+                Column.completed_at,
+                Operator.IN,
+                Type.Datetime,
+                Filters.value(
+                    datetime(2021, 11, 1),
+                    datetime(2021, 11, 5),
+                ),
+            ),
+        ],
+    )
 
-    assert filters == {'conjunction': 'or',
-                       'items': [
-                           {'filter': 'filter:tasks:id', 'operator': 'greater', 'type': 'Number', 'value': 42},
-                           {'filter': 'filter:tasks:completed_at', 'operator': 'in', 'type': 'Datetime',
-                            'value': {
-                                'min': '2021-11-01T00:00:00.000000Z',
-                                'max': '2021-11-05T00:00:00.000000Z'}
-                            }
-                         ]
-                       }
+    assert filters == {
+        'conjunction': 'or',
+        'items': [
+            {
+                'filter': 'filter:tasks:id',
+                'operator': 'greater',
+                'type': 'Number',
+                'value': 42,
+            },
+            {
+                'filter': 'filter:tasks:completed_at',
+                'operator': 'in',
+                'type': 'Datetime',
+                'value': {
+                    'min': '2021-11-01T00:00:00.000000Z',
+                    'max': '2021-11-05T00:00:00.000000Z',
+                },
+            },
+        ],
+    }
